@@ -12,6 +12,10 @@ from sympy.printing import cxxcode
 from sympy.printing.precedence import precedence
 
 
+C_MAX_INT = 2147483647
+C_MIN_INT = -2147483647
+
+
 class ChastePrinter(Printer):
     """
     Converts Sympy expressions to strings for use in Chaste code generation.
@@ -141,18 +145,19 @@ class ChastePrinter(Printer):
         return parts
 
     def _print_IntegerConstant(self, expr):
-        return cxxcode(int(expr), standard='C++11')
+        return self._print_int(float(expr))
 
     def _print_float(self, expr):
         """ Handles ``float``s. """
-        if expr.is_integer():
+        # print integers as int if they are between min & max int in c++
+        if expr.is_integer() and C_MIN_INT < expr < C_MAX_INT:
             return cxxcode(int(expr), standard='C++11')
         else:
-            return cxxcode(expr, standard='C++11')
+            return cxxcode(float(expr), standard='C++11')
 
     def _print_int(self, expr):
         """ Handles ``ints``s. """
-        return cxxcode(int(expr), standard='C++11')
+        return self._print_float(float(expr))
 
     def _print_ITE(self, expr):
         """ Handles ITE (if then else) objects by rewriting them as Piecewise """
